@@ -2,18 +2,20 @@ package Test::Pretty;
 use strict;
 use warnings;
 use 5.008001;
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 
 use Test::Builder 0.82;
 use Term::Encoding ();
 use File::Spec ();
-use Term::ANSIColor qw/colored/;
+use Term::ANSIColor ();
 use Test::More ();
 use Scope::Guard;
 use Carp ();
 
 use Cwd ();
 
+*colored = -t STDOUT ? \&Term::ANSIColor::colored : sub { $_[1] };
+
 my $SHOW_DUMMY_TAP;
 my $TERM_ENCODING = Term::Encoding::term_encoding();
 my $ENCODING_IS_UTF8 = $TERM_ENCODING =~ /^utf-?8$/i;
